@@ -9,10 +9,11 @@
 package DateTime::Util::Astro::Common;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK);
+use DateTime::Util::Astro;
 
 BEGIN
 {
-    $VERSION = '0.02';
+    $VERSION = $DateTime::Util::Astro::VERSION;
     @ISA = qw(Exporter);
     @EXPORT_OK = qw(
         aberration
